@@ -15,7 +15,7 @@ require Exporter;
                 reflect_shape rotate_shape
                 pour_sightly sightly);
 
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 my @C = map {"'" . chr() . "'"} 0..255;
 $C[39]  = q#"'"#;
@@ -362,7 +362,7 @@ sub pour_sightly {
                $outstr .= '(' x $tlen;
                my @itok = (')') x $tlen;
                splice(@ptok, $sidx+1, 0, @itok);
-               $iendprog += $tlen;
+               $iendprog += $tlen if $sidx < $iendprog;
             } else {
                my $n = _guess_ntok(\@ptok, $sidx, $tlen, \$exactfit);
                if ($exactfit) {
@@ -395,7 +395,7 @@ sub pour_sightly {
                      $outstr .= '(' x $nleft;
                      my @itok = (')') x $nleft;
                      splice(@ptok, $sidx+1, 0, @itok);
-                     $iendprog += $nleft;
+                     $iendprog += $nleft if $sidx < $iendprog;
                   } else {
                      $outstr .= $str;
                      $sidx += $n;
@@ -568,7 +568,7 @@ sub _make_banner {
    # /usr/games/banner character set:
    #    \ [ ] { } < > ^ _ | ~
    # Also must escape ' from the shell.
-   $src =~ tr#\\[]{}<>^_|~'`#/()()()H-!T""#;
+   $src =~ tr#_\\[]{}<>^|~'`#-/()()()H!T""#;
    my $str = "";
    my $i = 0; my $len = length($src);
    while ($i < $len) {
@@ -967,9 +967,9 @@ producing:
  ).+           (          ( '\\')).'\\'.  (    ( '`')|('.')).  (
  (((           (          (               (    (               (
  ((   (((     (           (               (    ((              (
- ((   (  '\\')             )              )     ))             )
- ))   )                     )             )     ) )            )
- ))   )  )))                 ))).'"'.';'.(       ( '!')^('+')).
+ ((   (  '\\')            )               )     ))             )
+ ))   )                   )               )     ) )            )
+ ))   )  )))               ))).'"'.(';').(       ( '!')^('+')).
  ((    (                              (          (          (
   (     (                            (          (           (
    (     (                            ( '"'    )            )
@@ -993,62 +993,62 @@ producing:
        )                          )))))))))))            )
 
 
-                      )))))))))))));(
-                    $^)=')'^'[';$/="\`"|
-                  '.';$_='('^'}';$,='`'|'!'
-                ;$\=                     ')'^
-              '}';                         ($:)
-            ='.'                             ^'~'
-           ;$~=                                 '@'|
-          '(';                                   ($^)
-         =')'                                     ^'['
-        ;$/=                                       '`'|
-       '.';                                         $_=
-       '('^                                         '}';
-      ($,)                                    ="\`"| '!';
-      ($\)                                =')'     ^  '}'
-      ;$:    =((                  ('.')))^          (  '~'
-     );(     (  $~))           =((                  (  '@'
-    )))      |      '(';$^=')'^                     (  '['
-    );(      (                                      (  $/)
-    ))=      (                                      (  '`'
-    ))|      (                                       ( '.'
-    ));     (                                        ( $_)
-     )=(    (                                        ( '('
-     ))     )                                        ^ '}'
-    ; $,    =                                        ( ((
-    (  ((  (                                         ( ((
-    (   '`')       )))))))))              )|'!';     $\=
-    (    ')'    )^+         '}'        ;$:      =((  '.'
-    ) )^  ((        '~'));$~             =('@')|      ((
-    ( (   ((      ((  '(')  ))    )    )) ));(  $^    )
-    = (  ')'       )^"\[";$/=     (    '`')|'.';$_    =
-    (  (( ((                      (                  (
-     (    ((                      (                 ((
-     (    '('                     )                 ))
-      )   )))                     )                )))
-       )))^'}'                    ;                $,=
-         "\`"|              (     (    (          '!'
-         )));(              (     (    (          $\)
-         )))=((             ')'))^'}';$:         ='.'
-         ^"\~";                                  ($~)
-         =('@')|         '(';$^=')'^"\[";$/=    '`'|
-          "\.";$_=    '('^'}';$,='`'|('!');$\= ')'^
-           "\}";$:=  ((                     "\."))^
-           '~';$~="\@"|  '(';$^=')'^'[';$/=  ('`')|
-            '.';$_='('      ^'}';$,="\`"|    "\!";
-             $\=')'^'}'                    ;($:)=
-              '.'^('~');$~=            '@'|"\(";
-               $^=')'^'[';$/='`'|'.';$_='('^'}'
-               ;$,='`'|'!';$\=')'^'}';$:=('.')^
-                '~';$~='@'|'(';$^=')'^('[');$/=
-                 '`'|'.';$_='('^'}';$,='`'|'!';
-                  $\=')'^'}';$:='.'^'~';$~='@'
-                    |'(';$^=')'^'[';$/=('`')|
-                     '.';$_='('^'}';$,="\`"|
-                       '!';$\=')'^('}');$:=
-                         '.'^'~';$~=('@')|
-                            '(';$^=')';
+                   )))))))))))));(
+                 $^)=')'^'[';$/="\`"|
+               '.';$_='('^'}';$,='`'|'!'
+             ;$\=                     ')'^
+           '}';                         ($:)
+         ='.'                             ^'~'
+        ;$~=                                 '@'|
+       '(';                                   ($^)
+      =')'                                     ^'['
+     ;$/=                                       '`'|
+    '.';                                         $_=
+    '('^                                         '}';
+   ($,)                                    ="\`"| '!';
+   ($\)                                =')'     ^  '}'
+   ;$:    =((                  ('.')))^          (  '~'
+  );(     (  $~))           =((                  (  '@'
+ )))      |      '(';$^=')'^                     (  '['
+ );(      (                                      (  $/)
+ ))=      (                                      (  '`'
+ ))|      (                                       ( '.'
+ ));     (                                        ( $_)
+  )=(    (                                        ( '('
+  ))     )                                        ^ '}'
+ ; $,    =                                        ( ((
+ (  ((  (                                         ( ((
+ (   '`')       )))))))))              )|'!';     $\=
+ (    ')'    )^+         '}'        ;$:      =((  '.'
+ ) )^  ((        '~'));$~             =('@')|      ((
+ ( (   ((      ((  '(')  ))    )    )) ));(  $^    )
+ = (  ')'       )^"\[";$/=     (    '`')|'.';$_    =
+ (  (  ((                      (                  (
+  (    ((                      (                 ((
+  (    '('                     )                 ))
+   )   )))                     )                )))
+    ))^'}';                    (                $,)
+      ='`'|              (     (    (          '!'
+      )));(              (     (    (          $\)
+      )))=((             ')'))^'}';$:         ='.'
+      ^"\~";                                  ($~)
+      =('@')|         '(';$^=')'^"\[";$/=    '`'|
+       "\.";$_=    '('^'}';$,='`'|('!');$\= ')'^
+        "\}";$:=  ((                     "\."))^
+        '~';$~="\@"|  '(';$^=')'^'[';$/=  ('`')|
+         '.';$_='('      ^'}';$,="\`"|    "\!";
+          $\=')'^'}'                    ;($:)=
+           '.'^('~');$~=            '@'|"\(";
+            $^=')'^'[';$/='`'|'.';$_='('^'}'
+            ;$,='`'|'!';$\=')'^'}';$:=('.')^
+             '~';$~='@'|'(';$^=')'^('[');$/=
+              '`'|'.';$_='('^'}';$,='`'|'!';
+               $\=')'^'}';$:='.'^'~';$~='@'
+                 |'(';$^=')'^'[';$/=('`')|
+                  '.';$_='('^'}';$,="\`"|
+                    '!';$\=')'^('}');$:=
+                      '.'^'~';$~=('@')|
+                         '(';$^=')';
 
 If you sincerely idolize Larry, you might put a picture frame
 around him:
@@ -1110,319 +1110,8 @@ to the program's source text:
                      SourceFile  => 'helloworld.pl',
                      Regex       => 1 } );
 
-The generated program, shown below, is easier to understand than
-the original because its characters are bigger and easier to read:
-
- ''                                        =~
- +(                                        ((
- '(')).'?'.'{'.('`'|'%').('['^'-').('`'|'!').
- ('`'|',').'"'.('['^'+').('['^')').('`'|')').
- ('`'|'.').('['^'/').('{'^'[').'\\'.'"'.('`'|
- '(').('`'|'%').('`'|',').('`'|',').('`'|'/')
-                    .+(                ((
-                  '{'                    ))
-                 ^((                      '['
-                 ))                       ).(
-                '['                       ^((
-                ',')                      )).
-                 ('`'                   |'/')
-                 .(('[')^           (')')).(
-                   '`'|',').('`'|'$').'\\'.
-                    '\\'.('`'|"\.").'\\'.
-                       '"'.';'.('!'^'+'
-
-                ).+                        ((
-                '"'                        ))
-                .'}'.')');$:='.'^'~';$~="\@"|
-                '(';$^=')'^'[';$/='`'|'.';$_=
-                '('^'}';$,='`'|'!';$\=')'^'}'
-                ;$:='.'^'~';$~='@'|'(';$^=')'
-                ^((                   '['
-                                       ));
-                                        $/=
-                                        '`'|
-                                        "\.";
-                                    $_=('(')^
-                                   '}';$,='`'
-                                   |('!');$\=
-                                   ')'^"\}";
-                                     ($:)
-
-                =((                        ((
-                '.'                        ))         ))^
-                '~';$~='@'|'(';$^=')'^'[';$/=       ('`')|
-                '.';$_='('^'}';$,='`'|'!';$\=      ')'^'}';
-                $:='.'^'~';$~='@'|'(';$^=')'^       '[';$/
-                ='`'|'.';$_='('^'}';$,=('`')|         '!'
-                ;$\
-
-                =((                        ((
-                ')'                        ))
-                ))^'}';$:='.'^'~';$~='@'|'(';
-                $^=')'^'[';$/='`'|'.';$_='('^
-                '}';$,='`'|'!';$\=')'^'}';$:=
-                '.'^'~';$~='@'|'(';$^=')'^'['
-                ;$/                     =(
-                                         ((
-                                         '`')
-                                         ))|+
-                                         '.';
-                $_=                     "\("^
-                '}';$,='`'|'!';$\=')'^'}';$:=
-                '.'^'~';$~='@'|'(';$^=')'^'['
-                ;$/='`'|'.';$_='('^"\}";$,=
-                '`'|'!';$\=')'^'}';$:='.'
-                ^((
-
-                                           ((
-                                           ((
-                      '~'))))));$~='@'|'(';$^=(')')^
-                   '[';$/='`'|'.';$_='('^'}';$,='`'|
-                 '!';$\=')'^'}';$:='.'^'~';$~=('@')|
-                '(';$^=')'^'[';$/='`'|'.';$_='('^'}'
-                ;($,)=                     ((
-                '`'))                      |+
-                 '!'
-                 ;$\
-                   =(
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-                                                     ')')^
-                                                    '}';$:=
-                                                   '.'^"\~";$~=
-                                                   '@'|'('
-                                                    ;($^)
-
-                =((                                            ((
-                ')'                                            ))
-                ))^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\=(')')^
-                '}';$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|"\.";
-                $_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^('~');$~=
-                '@'|'(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,="\`"|
-                '!'                     ;(
-                                         $\
-                                         )=((
-                                         ')')
-                                         )^((
-                '}'                     ));$:
-                ='.'^'~';$~='@'|'(';$^=(')')^
-                '[';$/='`'|'.';$_='('^'}';$,=
-                '`'|'!';$\=')'^'}';$:="\."^
-                '~';$~='@'|'(';$^=')'^'['
-                ;$/
-
-                          ='`'|'.';
-                       $_='('^"\}";$,=
-                     '`'|'!';$\=')'^'}';
-                   $:='.'^'~';$~='@'|"\(";
-                  $^=')'^     ((     '['));
-                 ($/)         =(        '`')
-                 |((          ((          '.'
-                )))           );           $_
-                =((           ((           ((
-                '('           ))           ))
-                 ))           ^+          '}'
-                 ;(           $,        )=((
-                  ((          ((     '`')))
-                   )))        |'!';$\=')'^
-                     ((       "\}"));$:=
-                              '.'^'~';
-
-                $~=                                            ((
-                '@'                                            ))
-                |'(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';
-                $\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^('[');$/=
-                '`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:="\."^
-                '~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^"\}";
-                $,=
-
-                '`'                                            |+
-                '!'                                            ;(
-                $\)=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^"\[";$/=
-                '`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:="\."^
-                '~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^"\}";
-                $,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|('(');$^=
-                ')'
-
-                          ^"\[";$/=
-                       '`'|'.';$_='('^
-                     '}';$,='`'|"\!";$\=
-                   ')'^'}';$:='.'^"\~";$~=
-                  '@'|'('            ;($^)=
-                 ')'^                   '[';
-                 $/=                      '`'
-                |((                        ((
-                '.'                        ))
-                ));                        $_
-                =((                       '('
-                 ))^                     '}';
-                 ($,)=                 "\`"|
-                   '!';$\=')'^'}';$:=('.')^
-                    '~';$~='@'|'(';$^=')'
-                      ^'[';$/='`'|"\.";
-                          $_=('(')^
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-                                           ((
-                                           ((
-                                        '}'))
-                                   ));$,='`'|
-                                '!';$\=(')')^
-                            '}';$:='.'^'~';$~
-                        ='@'|'(';$^="\)"^  ((
-                    '['));$/='`'|'.';
-                $_='('^'}';$,='`'
-                  |'!';$\="\)"^
-                      '}';$:
-                         =('.')^
-                      '~';$~='@'|'(';
-                 $^=')'^'[';$/='`'
-                  |'.';$_="\("^
-                      '}';$,
-                          ="\`"|
-                              '!';$\=
-                                ')'^'}'    ;(
-                                    $:)="\."^
-                                        "\~";
-                                           $~
-                                           =(
-                          '@')|'(';
-                       $^=')'^"\[";$/=
-                     '`'|'.';$_='('^'}';
-                   $,='`'|'!';$\=')'^"\}";
-                  $:='.'^            '~';$~
-                 ='@'                   |'('
-                 ;$^                      =((
-                ')'                        ))
-                ^((                        ((
-                '['                        ))
-                ));                       $/=
-                 '`'                     |'.'
-                 ;($_)                 ='('^
-                   '}';$,='`'|'!';$\=(')')^
-                    '}';$:='.'^'~';$~='@'
-                      |'(';$^=')'^"\[";
-                          $/=('`')|
-                '.'                        ;(
-                $_)                        =(
-                '(')^'}';$,='`'|'!';$\=(')')^
-                '}';$:='.'^'~';$~='@'|'(';$^=
-                ')'^'[';$/='`'|'.';$_='('^'}'
-                ;$,='`'|'!';$\=')'^'}';$:='.'
-                ^((                   '~'
-                                       ));
-                                        $~=
-                                        '@'|
-                                        "\(";
-                                    $^=(')')^
-                                   '[';$/='`'
-                                   |('.');$_=
-                                   '('^"\}";
-                                     ($,)
-
-                =((                                            ((
-                '`'                                            ))
-                ))|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=(')')^
-                '[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^"\}";
-                $:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|('.');$_=
-                '('^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~="\@"|
-                '('
-
-                         ;$^=')'^'[';
-                       $/='`'|('.');$_=
-                    '('^'}';$,='`'|'!';$\
-                   =')'^'}';$:='.'^"\~";$~=
-                 '@'|'(';           $^="\)"^
-                 '[';                   ($/)=
-                '`'|                      '.'
-                ;$_                       =((
-                 ((                       '('
-                 )))                      )^+
-                  '}'                    ;(
-                    $,)                =(                      ((
-                '`')))|'!';$\=')'^'}';$:='.'^'~';$~='@'|('(');$^=
-                ')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\="\)"^
-                '}';$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|"\.";
-                $_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^('~');$~=
-                '@'
-                |((
-
-                '(')
-                  );$^=
-                     "\)"^
-                        '[';$/
-                            ='`'|
-                               "\.";
-                                  ($_)=
-                                     "\("^
-                                       "\}";
-                                          ($,)=
-                                             "\`"|
-                                                '!';$\
-                                                   ="\)"^
-                                                       "\}";
-                                                          ($:)=
-                                                             '.'^
-
-                '~'                        ;(
-                $~)                        =(
-                '@')|'(';$^=')'^'[';$/=('`')|
-                '.';$_='('^'}';$,='`'|'!';$\=
-                ')'^'}';$:='.'^'~';$~='@'|'('
-                ;$^=')'^'[';$/='`'|'.';$_='('
-                ^((                     ((
-                                         ((
-                                         '}')
-                                         ))))
-                                         );$,
-                =((                     '`'))
-                |'!';$\=')'^'}';$:='.'^'~';$~
-                ='@'|'(';$^=')'^'[';$/=('`')|
-                '.';$_='('^'}';$,='`'|"\!";
-                $\=')'^'}';$:='.'^'~';$~=
-                '@'
-
-                                                     |'(';
-                                                    $^=')'^
-                                                   '[';$/="\`"|
-                                                   '.';$_=
-                                                    "\("^
-
-
-                   '}'                  ;$,
-                 ="\`"|                "\!";
-                $\="\)"^              '}';$:=
-            '.'^"\~";$~=              '@'|'('
-               ;$^=')'^                "\[";
+The generated program is easier to understand than the
+original because its characters are bigger and easier to read.
 
 Let's get more ambitious and create a big self-printing I<JAPH>.
 
@@ -1456,7 +1145,8 @@ is not reentrant. In this case, we must resort to:
 
 which runs the generated sightly program via C<eval> instead.
 If you want to use Regex => 1, ensure that the program to be
-converted does not use $_ and does not use any regular expressions.
+converted does not use any regular expressions (and is careful
+with use of C<$_>).
 
 To produce a I<JAPH> that resembles the original
 I<Just another Perl hacker,> aka I<Randal L Schwartz>, try this:
@@ -1517,6 +1207,128 @@ producing:
                   #;#           ;#
                       ;#;#;#;#;
 
+Because the sightly encoding is not very compact, you sometimes
+find yourself playing a surreal form of I<Perl Golf>, where
+the winner is the one with the smallest F<f.tmp> in:
+
+    sightly.pl -r -f program_to_be_converted >f.tmp
+
+Apart from reducing the (key-)stroke count, you should strive
+to replace alphanumeric characters with sightly ones, because
+they do not require encoding.
+
+To illustrate, consider the intriguing problem of creating
+I<Buffy looking in the mirror>. Let's start with F<k.pl>:
+
+    open$[;chop,($==y===c)>$-&&($-=$=)for@:=<0>;
+    print$"x-(y---c-$-).reverse.$/for@:
+
+Notice that EyeDrops-generated programs contain no trailing
+spaces, which complicates the above program.
+
+Buffy looking in the mirror can now be created with:
+
+    sightly.pl -r -f k.pl -s buffy2 >b.pl
+    cat b.pl        (should show Buffy's face)
+    perl b.pl       (should show Buffy looking in the mirror)
+
+Drat. This requires two buffy2 shapes. What to do?
+Since significantly shortening F<k.pl> above seems unlikely
+(but if you do, please let me know!), we resort to writing
+a post processor program, F<pp.pl>, to append the required
+number of spaces to each line:
+
+    chop,$==y===c,$=<$-or$-=$=for@a=<>;
+    print$_.($"x($--length)).$/for@a
+
+With this program in place, we can write a briefer F<kk.pl>:
+
+    open$%;chop,print+reverse.$/for<0>
+
+and finally produce Buffy looking in the mirror with:
+
+    sightly.pl -r -f kk.pl -s buffy2 >b.pl
+    perl pp.pl b.pl >bb.pl
+    cat bb.pl        (should show Buffy's face)
+    perl bb.pl       (should show Buffy looking in the mirror)
+
+Interestingly, showing the face upside down, rather than
+reflected, is more easily solved with:
+
+    open$%;print+reverse<0>
+
+and easier still for a self-printing shape:
+
+    open$%;print<0>
+
+To combine I<Buffy looking in the mirror> with a (cheating) quine,
+we create F<m.pl>:
+
+    $:=pop||'';open$[;print+map$:eq'mirror'?chop&&reverse.$/:$_,<0>
+
+and:
+
+    sightly.pl -r -f m.pl -s buffy2 >b.pl
+    perl pp.pl b.pl >buffy.pl
+    cat buffy.pl           (should show Buffy's face)
+    perl buffy.pl          (should show Buffy's face again)
+    perl buffy.pl mirror   (should show Buffy looking in the mirror)
+
+producing:
+
+                    ''=~('('.'?'                                
+                 .'{'.('`'|"\%").(                              
+               '['^'-').('`'|'!').(                             
+              '`'               | ','                           
+             ).+                (  '"'                          
+            ).+                 (   (((                         
+           (((                  (   (((                         
+          (((                  (     (((                        
+         (((              '\\'))      )))                       
+         )))          ))))      )     )))                       
+        )))       )).+           (     '$'                      
+        ).+     ((                (     ':'                     
+        )))    .                   (    '='                     
+        ).(   (                     ('['))^                     
+       '+'    )                      . (  (                     
+       (   '`') )|'/')      .('['^     (  (                     
+       (  (  ((                        (  (                     
+       (  (      ( (( (     ( (( (     (   (                    
+       (  (       '+')       ))))      )   )                    
+       )   )                        )))    )                    
+       )    )))                     )      )                    
+       ))      )       )   .        (     ((                    
+       '|'      )        )          )    .((                    
+        '|'))."'"                   ."'".';'                    
+        .('`'|'/'    ).(('[')^     ('+')).(                     
+        '`'|'%').(     "\`"|     ( ('.'))).                     
+        '\\'.'$'.'['            .  (';').(                      
+        '['^'+').('['          ^   "\)").(                      
+        '`'|')').('`' |      (     '.')).(                      
+        '['^'/').'+'.     (        ('`')| (                     
+        '-')).("\`"|              "\!").(   (                   
+        '[')^('+')).              ('\\').     (                 
+         '$')."\:".(             '`'|'%')     .("\["^           
+         '*')."\'".(             '`'|'-'      )      .("\`"|    
+   ')').('['^')').(            ( "\[")^       (             (   
+  (    ( ')'))))).( (        (   '`'))        |              (  
+ (     ( "\/")))).(   (   (     '['))         ^              (  
+ (     ')')))."'".       (     '?')           .              (  
+ (    '`')|'#').(        (                    (               ( 
+ (     '`'))))|          (                    (               ( 
+ (     ( '(')                                 )               ) 
+ )     )                                      )               . 
+ (     (                                      (               ( 
+ (     (                                      (      (         (
+ (     (                                      (      (         (
+ (     (                                      (     (          (
+ (     (                                      (     (          (
+ (     '`'))))))))))))))))))))))))|'/').(('[')^    (           (
+ (    '+')))).'&'.'&'.('['^')').('`'|'%').('['^'-')            .
+ (    '`'|'%').('['^')').('['^'(').('`'|'%').'.'.''.           (
+ (   '\\')).'$'.'/'.':'.'\\'.'$'.'_'.','.'<'.(('^')^(          (
+ (   '`'))|'.')).'>'.('!'^'+').'"'.'}'.')');$:='.'^'~'         ;
+
 But wait, there's more. You can encode binary files too.
 
     print sightly({Shape      => 'camel,mongers',
@@ -1553,14 +1365,14 @@ Just one camel needed for this little program.
     cat t2.pl
     perl t2.pl
 
-Hmm. 13 camels now.
+Hmm. 14 camels now.
 
     sightly.pl -r -s camel -f t2.pl >t3.pl
     ls -l t3.pl
     cat t3.pl
     perl t3.pl
 
-163 camels. 412,064 bytes. Hmm. Getting slower.
+195 camels. 563,745 bytes. Hmm. Getting slower.
 Is this the biggest, slowest I<hello world> program ever written?
 
     sightly.pl -r -s camel -f t3.pl >t4.pl
@@ -1572,45 +1384,53 @@ Is this the biggest, slowest I<hello world> program ever written?
 
 Here is the original one camel program, F<t1.pl>:
 
-                                         ''=~+(
-                                        '('.'?' .'{'.
-            ('`' |                  '%').("\["^ '-').(
-        '`'|"\!").(               '`'|',').'"'.( ('[')^
-   ('+')).(  "\["^ (             ')')).('`'|')').(('`')|
- '.').('['^'/').('{'^           '[').'\\'.'"'.('`'|'(').
- ('`'|'%').('`'|',').(        '`'|',').('`'|'/').('{'^'[')
-  .('['^',').('`'|'/')     .('['^')').('`'|',').('`'|'$').'\\'
-             .'\\'.(       '`'|'.').'\\'.'"'.';'.('!'^'+').'"'.
-       '}'.')');$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('
-       ^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^"\[";
-      $/='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~="\@"|
-       '(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^"\}";$:=
-       '.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';
-       $\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_="\("^
-      '}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^('[');$/=
-       '`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';
-         $^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}' ;($:)=
-          '.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^'}';   ($,)=
-            '`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=(')')^   "\[";
-              $/='`'|'.';$_='('^'}';$,='`'|'!';$\=')' ^'}';$:=   '.'^
-                ((   '~'));$~='@'|'(';$^=')'^"\[";$/= '`'|'.';  ($_)
-                     ='('^"\}";  $,='`'|'!' ;$\=')'^   '}';$:=  '.'
-                     ^('~');$~=  '@'|'(';$^ =')'^'['    ;$/='`' |+
-                      "\.";$_=   '('^'}';$,  =('`')|     '!';$\
-                      =')'^'}'  ;$:=('.')^   '~';$~=      "\@"|
-                      '(';$^=   ')'^'[';$/    ="\`"|      '.';$_
-                      =('(')^   "\}";$,=      ('`')|       "\!";
-                      $\=')'    ^"\}";       $:='.'        ^'~';
-                       ($~)=     ('@')|     '(';$^         =')'^
-                       "\[";      $/='`'|  '.';$_          ='('
-                       ^'}';         $,='`'|'!'            ;$\=
-                       ')'^           "\}";$:=             '.'^
-                       '~';            $~=('@')|           '(';
-                      ($^)            =')'^'[';$/         ='`'|
-                     "\.";         $_='('^'}';$,=         ('`')|
-                     "\!";        $\="\)"^  '}';         $:='.'^
-                   '~';$~=                              '@'|'(';
-                 $^="\)"^                                '[';#;
+                                       ''=~('('.'?'
+            .'{'.(                   '`'|'%').("\["^
+         '-').('`'|                '!').('`'|',').'"'
+  .('['^'+')  .('['^              ')').('`'|')').('`'|
+ '.').('['^'/').('{'^            '[').'\\'.'"'.('`'|'('
+ ).('`'|'%').('`'|',')          .('`'|',').('`'|"\/").(
+   '{'^'[').('['^',').        ('`'|'/').('['^')').("\`"|
+        ',').('`'|'$')      .'\\'.'\\'.('`'|'.').'\\'.'"'
+       .';'.('!'^'+')     .'"'.'}'.')');$:='.'^'~';$~='@'|
+      '(';$^=')'^'[';   $/='`'|'.';$_='('^'}';$,='`'|'!';$\
+     =')'^'}';$:='.'   ^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';
+     $_='('^"\}";$,=  '`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'('
+     ;$^=')'^'[';$/  ='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}'
+     ;$:='.'^'~';$~  ='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^'}';
+     $,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^'[';$/=
+     '`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|
+      '(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\=')'^'}'
+      ;$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('^'}';$,=
+       '`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|
+        '.';$_='('^'}';$,='`'|'!';$\=')'^'}';$:='.'^'~';$~='@'|'('
+         ;$^=')'^'[';$/='`'|'.';$_='('^'}';$,='`'|'!';$\="\)"^ '}'
+          ;$:='.'^'~';$~='@'|'(';$^=')'^'[';$/='`'|'.';$_='('  ^((
+           '}'));$,='`'|'!';$\=')'^'}';$:='.'^'~';$~ ='@'|'('  ;$^
+             =')'^'[';$/='`'|'.';$_='('^'}';$,='`'|  '!';$\=   ')'
+              ^'}'; $:='.'^'~';$~='@'|'(';$^="\)"^   '[';$/=   '`'
+                    |'.';$_='('^'}';$,='`'|'!';$\    =(')')^   '}'
+                    ;$:='.'^    '~';$~='@' |"\(";     $^=')'   ^+
+                    '[';$/=     '`'|'.';   $_='('     ^"\}";  $,
+                    =('`')|     "\!";$\=   "\)"^       "\}";  (
+                    ($:))=      '.'^'~';   ($~)         ='@'
+                    |"\(";     $^=(')')^   '[';         ($/)
+                     ='`'|     "\.";$_=    '('^         '}';
+                     ($,)=     '`'|'!'     ;$\=         ')'^
+                     '}';     $:='.'       ^'~'         ;$~=
+                     '@'|     '('          ;$^=         ')'^
+                     '[';      $/=         '`'          |((
+                     '.'        ));       $_=           '('
+                     ^((         '}'     ));            $,=
+                     '`'          |((   '!'              ))
+                     ;(             ($\))=               ((
+                     ((              ')'))               ))
+                     ^+             "\}";$:=             ((
+                    '.'            ))^+ "\~";            $~
+                   =((           '@'))|  '(';           $^=
+                  ')'^         "\[";$/=   '`'          |'.'
+                ;($_)=                                ('(')^
+              "\}";$,=                               '`'|'!'
 
 Buffy fans might like to rotate her letters:
 
@@ -1984,11 +1804,13 @@ EyeDrops are:
     eugene      World's No. 1 Perl golfer, Eugene van der Pijll
     golfer      A golfer hitting a one iron
     japh        JAPHs were invented by Randal L Schwartz in 1988
+    kermit      Kermit the frog
     larry       Larry Wall's face
     larry2      Caricature of Larry contributed by Ryan King
     london      Haiku "A Day in The Life of a London Perl Monger"
     merlyn      Just another Perl hacker, aka Randal L Schwartz
     mongers     Perl Mongers logo
+    pgolf       Perl Golf logo (inspired by `/anick)
     pony        Horizontal banner of "Pony"
     pony2       Picture of a Pony
     riding      Horizontal banner of "riding"
@@ -2009,8 +1831,8 @@ A really diabolical shape with lots of single character lines
 will defeat the shape-pouring algorithm.
 
 You can eliminate all alphanumerics (via Regex => 1) only if the
-program to be converted does not use regular expressions and does
-not use C<$_>.
+program to be converted does not use regular expressions and is
+careful with use of C<$_>.
 To convert complex programs, you must use Regex => 0, which
 emits a leading unsightly C<eval>.
 
@@ -2037,7 +1859,7 @@ in place of the Linux banner command.
 
 =head1 AUTHOR
 
-Andrew Savige <andrew.savige@ir.com>
+Andrew Savige <asavige@cpan.org>
 
 =head1 SEE ALSO
 
